The ``ellipse`` folder contains configuration files for the default priors assumed for ``ellipse`` objects.

These model components are used for ellipse isophote fitting, which models the surface brightness of a galaxy as a
series of ellipses, which can include multipole perturbations.

The main object used for modeling is the `Ellipse` object, with a list of `Ellipse` objects used to model the galaxy.